@@ -30,7 +30,13 @@ class _BaseTestDB(object):
         dname = tempfile.mkdtemp(prefix='taskw-tests-data')
 
         with open(fname, 'w') as f:
-            f.writelines(['data.location=%s' % dname])
+            f.writelines([
+                'data.location=%s\n' % dname,
+                'uda.somestring.label=Testing String\n',
+                'uda.somestring.type=string\n',
+                'uda.somedate.label=Testing Date\n',
+                'uda.somedate.type=date\n',
+            ])
 
         # Create empty .data files
         for piece in ['completed', 'pending', 'undo']:
@@ -185,6 +191,28 @@ class _BaseTestDB(object):
         # ... we'll just "roughly" test it instead of mocking.
         assert(tasks['pending'][0]['entry'].startswith("20110101T"))
 
+    def test_add_with_uda_string(self):
+        self.tw.task_add(
+            "foobar",
+            somestring="this is a uda",
+        )
+        tasks = self.tw.load_tasks()
+        eq_(len(tasks['pending']), 1)
+        task = tasks['pending'][0]
+
+        eq_(task['somestring'], "this is a uda")
+
+    def test_add_with_uda_date(self):
+        self.tw.task_add(
+            "foobar",
+            somedate=datetime.datetime(2011, 1, 1),
+        )
+        tasks = self.tw.load_tasks()
+        eq_(len(tasks['pending']), 1)
+        task = tasks['pending'][0]
+
+        assert(task['somedate'].startswith("20110101T"))
+
     @raises(ValueError)
     def test_completing_completed_task(self):
         task = self.tw.task_add("foobar")
@@ -365,6 +393,17 @@ class TestDBShellout(_BaseTestDB):
         eq_(len(tasks), 1)
         eq_(tasks[0]['id'], 3)
 
+    def test_filtering_double_dash(self):
+        task1 = self.tw.task_add("foobar1")
+        task2 = self.tw.task_add("foobar2")
+        task2 = self.tw.task_add("foo -- bar")
+        tasks = self.tw.filter_tasks({
+            'description.contains': 'foo -- bar',
+        })
+        eq_(len(tasks), 1)
+        eq_(tasks[0]['id'], 3)
+        eq_(tasks[0]['description'], 'foo -- bar')
+
     def test_filtering_logic_disjunction(self):
         task1 = self.tw.task_add("foobar1")
         task2 = self.tw.task_add("foobar2")
